@@ -1,5 +1,5 @@
 /* Quinn Diff, Determine which packages need recompiled for any given architecture */
-/* Copyright (C) 1997-1999, James Troup <james@nocrew.org> */
+/* Copyright (C) 1997-2001, James Troup <james@nocrew.org> */
 
 /* This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,12 +20,11 @@
 #include <stdlib.h>
 #include <string.h>
 #include <glib.h>
-#include "arch_specific.h"
-#include "common.h"
+#include "globals.h"
 #include "error.h"
-#include "main.h"
 #include "utils.h"
 #include "xmalloc.h"
+#include "arch_specific.h"
 
 /* Used to stop quinn diff trying to parse Packages-arch-specific
    files which it can't */
@@ -47,22 +46,22 @@ arch_specific_packages_ht_create (void)
 {
 
   arch_specific_packages_hash_table = g_hash_table_new (quinn_hash_function, quinn_key_compare_function);
-  
+
   if (arch_specific_packages_hash_table == NULL)
     fubar (SYSERR, "Unable to create hash table for architecture specific packages.");
 
 }
 
-void 
+void
 arch_specific_packages_read (void)
 {
 
-  FILE *fp = NULL; 
+  FILE *fp = NULL;
   char *buffer_p;
   unsigned long buffer_length;
 
   open_arch_specific_file (fp, &buffer_p, &buffer_length);
-  debug (debug_as, "read_arch_specific_file: read %ld bytes of \"%s\"", 
+  debug (debug_as, "read_arch_specific_file: read %ld bytes of \"%s\"",
 	buffer_length, packages_arch_specific_filename);
 
   read_arch_specific_packages (buffer_p, buffer_length);
@@ -70,7 +69,7 @@ arch_specific_packages_read (void)
 
 }
 
-boolean 
+boolean
 is_arch_specific (char *package)
 {
 
@@ -94,15 +93,15 @@ arch_specific_packages_ht_destroy (void)
 
   g_hash_table_foreach (arch_specific_packages_hash_table, arch_specific_package_free_ht_entry, NULL);
   g_hash_table_destroy (arch_specific_packages_hash_table);
-  
+
 }
 
 void
-arch_specific_package_free_ht_entry (gpointer key, 
-				     gpointer package __attribute__ ((unused)), 
+arch_specific_package_free_ht_entry (gpointer key,
+				     gpointer package __attribute__ ((unused)),
 				     gpointer cruft __attribute__ ((unused)))
 {
-  
+
   xfree (key);
 
 }
@@ -111,7 +110,7 @@ arch_specific_package_free_ht_entry (gpointer key,
 
 void open_arch_specific_file(FILE *fp, char **buffer_p, long *buffer_length)
 {
-  long n_read;                   
+  long n_read;
 
   fp = fopen (packages_arch_specific_filename, "r");
   if (fp == NULL)
@@ -142,7 +141,7 @@ void open_arch_specific_file(FILE *fp, char **buffer_p, long *buffer_length)
 	   program_name, n_read, *buffer_length, packages_arch_specific_filename);
 
   if (fclose (fp) == EOF)
-    fubar (SYSERR, "%s: couldn't close file \"%s\"", program_name, 
+    fubar (SYSERR, "%s: couldn't close file \"%s\"", program_name,
 	   packages_arch_specific_filename);
 }
 
@@ -151,7 +150,7 @@ void read_arch_specific_packages (const char *buffer_p, const unsigned long buff
 {
 
   char *line;
-  char *architectures; 
+  char *architectures;
   char *package_name;
   unsigned long i;
   unsigned int j, k, l;
@@ -159,7 +158,7 @@ void read_arch_specific_packages (const char *buffer_p, const unsigned long buff
   check_parseable (buffer_p, buffer_length);
 
   i = 0;
-  
+
   while (i < buffer_length)
     {
 
@@ -170,7 +169,7 @@ void read_arch_specific_packages (const char *buffer_p, const unsigned long buff
 	  skip_line (buffer_p, &i, buffer_length);
 	  continue;
 	}
-      
+
       line = read_line (buffer_p, buffer_length, &i);
 
       /* Parse the line by splitting it up into package name and the packages' supported architectures */
@@ -192,11 +191,11 @@ void read_arch_specific_packages (const char *buffer_p, const unsigned long buff
       k = 0;
       j = strlen (line) - l;
       architectures = xmalloc (j + 1);
-      while (k < j && buffer_p[l] != '#')
+      while (k < j && line[l] != '#')
 	architectures[k++] = line[l++];
       architectures[k] = '\0';
       debug(debug_as, "architectures are \"%s\"", architectures);
-      
+
       /* Check for "!arch" or "arch" */
 
       if (strchr (architectures, '!') != NULL)
@@ -205,7 +204,7 @@ void read_arch_specific_packages (const char *buffer_p, const unsigned long buff
 	     not !arch there is support for arch */
 	  if (strstr (architectures, packages_architecture) != NULL)
 	    {
-	      debug (debug_as, "read_arch_specficic_packages: %s doesn't need compiled on %s", 
+	      debug (debug_as, "read_arch_specficic_packages: %s doesn't need compiled on %s",
 		     package_name, packages_architecture);
 	      arch_specific_packages_ht_add(package_name);
 	    }
@@ -215,16 +214,16 @@ void read_arch_specific_packages (const char *buffer_p, const unsigned long buff
 	  /* "arch" is inclusionary; if arch is not listed, it's not
 	     supported by the package */
 	  if (strstr (architectures, binary_architecture_match) != NULL)
-	    debug (debug_as, "read_arch_specficic_packages: %s has %s support", 
+	    debug (debug_as, "read_arch_specficic_packages: %s has %s support",
 		   package_name, binary_architecture_match);
 	  else
 	    {
-	      debug (debug_as, "read_arch_specficic_packages: %s doesn't need compiled on %s", 
+	      debug (debug_as, "read_arch_specficic_packages: %s doesn't need compiled on %s",
 		     package_name, binary_architecture_match);
 	      arch_specific_packages_ht_add(package_name);
 	    }
 	}
-      
+
       xfree (line);
       xfree (package_name);
       xfree (architectures);
