@@ -1,5 +1,5 @@
 /* Quinn Diff, Determine which packages need recompiled for any given architecture */
-/* Copyright (C) 1997-1999, James Troup <james@nocrew.org> */
+/* Copyright (C) 1997-2001, James Troup <james@nocrew.org> */
 
 /* This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -19,17 +19,17 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include "common.h"
 #include "config.h"
 #include "error.h"
 #include "getopt.h"
+#include "globals.h"
 #include "init.h"
 #include "parse_packages.h"
 #include "parse_sources.h"
 #include "utils.h"
 #include "xmalloc.h"
 
-void 
+void
 parse_opt (int argc, char **argv, sources_info *sources, packages_info *packages)
 {
   char *debug_argument;
@@ -41,8 +41,10 @@ parse_opt (int argc, char **argv, sources_info *sources, packages_info *packages
       static struct option long_options[] =
       {
 	{"arch-specific-packages", required_argument, NULL, 'a'},
+	{"architecture", required_argument, NULL, 'A'},
 	{"debug", required_argument, NULL, 'D'},
 	{"help", no_argument, NULL, 'h'},
+	{"ignore-arch-all", no_argument, NULL, 'i'},
 	{"sources", required_argument, NULL, 's'},
 	{"packages", required_argument, NULL, 'p'},
 	{"version", no_argument, NULL, 'V'},
@@ -50,7 +52,7 @@ parse_opt (int argc, char **argv, sources_info *sources, packages_info *packages
 	{0, 0, 0, 0}
       };
 
-      c = getopt_long (argc, argv, "a:D:p:s:w:hV",
+      c = getopt_long (argc, argv, "a:A:D:hip:s:w:V",
 		       long_options, &option_index);
       if (c == EOF)
 	break;
@@ -62,6 +64,11 @@ parse_opt (int argc, char **argv, sources_info *sources, packages_info *packages
 	  packages_arch_specific_filename = xstrdup (optarg);
 	  break;
 
+	case 'A':
+	  xfree_if_non_null (packages_architecture);
+	  packages_architecture = xstrdup (optarg);
+	  break;
+
 	case 'D':
 	  if (!strcmp (optarg, "help"))
 	    debug_help();
@@ -80,6 +87,10 @@ parse_opt (int argc, char **argv, sources_info *sources, packages_info *packages
 	  usage (0);
 	  break;
 
+	case 'i':
+	  ignore_arch_all = TRUE;
+	  break;
+
 	case 'p':
 	  xfree_if_non_null (packages->file_name);
 	  packages->file_name = xstrdup (optarg);
@@ -108,7 +119,7 @@ parse_opt (int argc, char **argv, sources_info *sources, packages_info *packages
 	}
     }
 
-   if (optind != argc)  
+   if (optind != argc)
      {
        error ("Quinn diff no longer accepts non-option arguments.");
        usage(1);
@@ -122,13 +133,16 @@ usage (int status)
   fprintf (status ? stderr : stdout, "Usage: %s [-apswhDV]\n\
 -a --arch-specific-packages  filename of Packages-arch-specific file.\n\
                               default: /etc/Packages-arch-specific\n\
+-A --architecture=<arch>     architecture of Packages file.\n\
+                              default is auto-detected\n\
 -D --debug=<octal value>     enable debug output; see -Dhelp or --debug=help\n\
 -h --help                    give this help\n\
+-i --ignore-arch-all         ignore Architecture: all source packages\n\
 -p --packages                filename of Packages file.\n\
                               default: Packages in cwd\n\n
--s --source-packages        filename of Sources file.\n\
+-s --source-packages         filename of Sources file.\n\
                               default: Sources in cwd\n\
--w --warn-older              warn about packages older on primary\n\
+-w --warn-older              warn about packages older in Sources file\n\
 -V --version                 display version number\n", program_name);
   exit (status);
 
