@@ -1,5 +1,5 @@
 /* Quinn Diff, Determine which packages need recompiled for any given architecture */
-/* Copyright (C) 1997-1999, James Troup <james@nocrew.org> */
+/* Copyright (C) 1997-2001, James Troup <james@nocrew.org> */
 
 /* This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,7 +22,6 @@
 #include "arch_specific.h"
 #include "error.h"
 #include "init.h"
-#include "main.h"
 #include "output.h"
 #include "parse_sources.h"
 #include "parse_packages.h"
@@ -32,7 +31,7 @@
 /* The following causes "common.h" to produce definitions of all the global
    variables, rather than just "extern" declarations of them. */
 #define GLOBAL
-#include "common.h"
+#include "globals.h"
 
 int
 main (int argc, char **argv)
@@ -40,9 +39,9 @@ main (int argc, char **argv)
 
   sources_info *sources;
   packages_info *packages;
-  
+
   sources = xmalloc (sizeof(*sources));
-  sources->name = NULL; 
+  sources->name = NULL;
   sources->section = NULL;
   sources->priority = NULL;
   sources->version = NULL;
@@ -55,12 +54,13 @@ main (int argc, char **argv)
 
   debug_level = 0;
   warn_older = FALSE;
+  ignore_arch_all = FALSE;
   program_name = argv[0];
   sources->buffer_pos = 0;
   packages->buffer_pos = 0;
   sources->file_name = xstrdup ("Sources");
   packages->file_name = xstrdup ("Packages");
-  packages_arch_specific_filename = xstrdup ("/etc/Packages-arch-specific"); 
+  packages_arch_specific_filename = xstrdup ("/etc/Packages-arch-specific");
   packages_architecture = NULL;
   parse_opt (argc, argv, sources, packages);
 
@@ -72,18 +72,18 @@ main (int argc, char **argv)
 
   /* Read and process the Packages file */
 
-  read_file (packages->file_name, packages->file_pointer, &packages->buffer, &packages->file_length); 
+  read_file (packages->file_name, packages->file_pointer, &packages->buffer, &packages->file_length);
   determine_packages_architecture (packages);
   process_packages (packages);
   xfree (packages->buffer);
 
   /* Read and process Packages-arch-specific */
 
-  arch_specific_packages_read (); 
+  arch_specific_packages_read ();
 
   /* Read and process the Sources file */
 
-  read_file (sources->file_name, sources->file_pointer, &sources->buffer, &sources->file_length); 
+  read_file (sources->file_name, sources->file_pointer, &sources->buffer, &sources->file_length);
   parse_sources (sources);
 
   /* Display the output */
@@ -91,7 +91,7 @@ main (int argc, char **argv)
   output_display_all ();
 
   /* Cleanup */
-  
+
   packages_ht_destroy ();
   arch_specific_packages_ht_destroy ();
   output_ht_destroy ();
@@ -102,5 +102,5 @@ main (int argc, char **argv)
   xfree (binary_architecture_match);
 
   return (0);
-      
+
 }
