@@ -1,5 +1,5 @@
 /* Quinn Diff, Determine which packages need recompiled for any given architecture */
-/* Copyright (C) 1997-1999, James Troup <james@nocrew.org> */
+/* Copyright (C) 1997-2001, James Troup <james@nocrew.org> */
 
 /* This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -18,18 +18,15 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <sys/types.h>
-#include <limits.h>
-#include <fcntl.h>
 #include <string.h>
 #include <glib.h>
-#include "common.h"
+#include "globals.h"
 #include "error.h"
-#include "main.h"
 #include "output.h"
 #include "parse_sources.h"
 #include "utils.h"
 #include "xmalloc.h"
+#include "vercmp.h"
 
 GHashTable *output_hash_table;
 
@@ -53,8 +50,29 @@ output_ht_add (const sources_info *source, const char *binary_version,
 {
 
   output_info *package_to_add;
+  output_info *old_package;
+  int i;
+  
+  /* Check for duplicates */ 
 
-  debug(debug_output, "output_add: Adding \"%s\" (%s:%s) [Versions %s and %s] to output hash table", 
+  old_package = output_ht_retrieve (source->name);
+  if (old_package)
+    { 
+
+      /* Update the compiled flag, regardless of duplicity. */
+      if (!old_package->compiled && binary_version)
+	{
+	  debug (debug_output, "output_ht_add: duplicate, but this one has binary_version so flipping compiled on. [%s]", source->name);
+	  old_package->compiled = TRUE;
+	}
+
+      i = compare_versions (source->version, old_package->source_version, source->name);
+      debug (debug_output, "output_ht_add: %s is duplicated [%d]", source->name, i);
+      if (i >= 0)
+	return;
+    }
+
+  debug(debug_output, "output_ht_add: Adding \"%s\" (%s:%s) [Versions %s and %s] to output hash table", 
 	source->name, source->priority, source->section, source->version, binary_version);
 
   /* Set up the output_info node for this package */
@@ -63,9 +81,15 @@ output_ht_add (const sources_info *source, const char *binary_version,
   package_to_add->name = xstrdup (source->name);  
   package_to_add->source_version = xstrdup (source->version);  
   if (binary_version)
-    package_to_add->binary_version = xstrdup (binary_version);
+    {
+      package_to_add->binary_version = xstrdup (binary_version);
+      package_to_add->compiled = TRUE;
+    }  
   else
-    package_to_add->binary_version = NULL;
+    {
+      package_to_add->binary_version = NULL;
+      package_to_add->compiled = FALSE;
+    }
   package_to_add->priority = xstrdup (source->priority);  
   package_to_add->section = xstrdup (source->section);  
   package_to_add->compare_versions_result = compare_versions_result;
@@ -108,10 +132,10 @@ output_display_package (gpointer key __attribute__ ((unused)),
 
   package = (output_info *) xpackage;
 
-  if (!package->binary_version)
-    strcpy (status, "uncompiled");
-  else
+  if (package->compiled)
     strcpy (status, "out-of-date");
+  else
+    strcpy (status, "uncompiled");
 
   if (!package->binary_version || package->compare_versions_result < 0)
     printf ("%s/%s_%s.dsc [%s:%s]\n", 
