@@ -1,5 +1,5 @@
 /* Quinn Diff, Determine which packages need recompiled for any given architecture */
-/* Copyright (C) 1997-1999, James Troup <james@nocrew.org> */
+/* Copyright (C) 1997-2001, James Troup <james@nocrew.org> */
 
 /* This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -25,18 +25,19 @@ struct _packages_info {
   char *file_name;
   FILE *file_pointer;
   long file_length;
-  char *buffer;		
+  char *buffer;
   long buffer_pos;
-  char *name;   
+  char *name;
   char *version;
   char *source;
+  char *architecture;
 };
 
 void determine_packages_architecture (packages_info *packages);
 void process_packages (packages_info *packages);
 void packages_ht_create (void);
 void packages_ht_add (char *package, char *version);
-char *packages_ht_lookup (char *package);
+char *packages_ht_lookup (const char *package);
 void packages_ht_destroy(void);
 
 #endif /* __PARSE_PACKAGES_H__ */
