@@ -1,5 +1,5 @@
 /* Quinn Diff, Determine which packages need recompiled for any given architecture */
-/* Copyright (C) 1997-1999, James Troup <james@nocrew.org> */
+/* Copyright (C) 1997-2001, James Troup <james@nocrew.org> */
 
 /* This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,7 +22,6 @@
 #include "common.h"
 #include "error.h"
 #include "list.h"
-#include "main.h"
 #include "utils.h"
 #include "xmalloc.h"
 
@@ -41,11 +40,11 @@ quinn_hash_function (gconstpointer keyarg)
   unsigned int h;
   unsigned char c;
   unsigned int len;
-  
+
   len = strlen (keyarg);
   key = keyarg;
   e = key + len;
-  for (h = 0; key != e;) 
+  for (h = 0; key != e;)
     {
       c = *key++;
       if (!c && key > e)
@@ -67,12 +66,13 @@ quinn_key_compare_function (gconstpointer a, gconstpointer b)
 /* Non-destructively searches one packages' entry for interesting (as
    defined by the want list) information.*/
 
-void parse_package (const char *buffer, long buffer_position, const int buffer_length, 
-		    Qlist *want_list, const char *package_name)
+long
+parse_package (const char *buffer, long buffer_position, const int buffer_length,
+	       Qlist *want_list)
 {
 
   char *line;
-  Qlist *want_list_pointer; 
+  Qlist *want_list_pointer;
   int i;
 
   /* Initialize the want list */
@@ -89,23 +89,24 @@ void parse_package (const char *buffer, long buffer_position, const int buffer_l
       want_list_pointer = want_list_pointer->next;
     }
 
-  debug (debug_utils, "parse_package: parsing %s", package_name);
+  debug (debug_utils, "parse_package: inside parse_packages...");
 
   while (buffer[buffer_position] != '\n'  && buffer_position < buffer_length)
     {
       want_list_pointer = want_list;
 
       /* We're not interested in descriptions, so we skip any lines that start with a space. */
-      if (buffer[buffer_position] == ' ')  
+      if (buffer[buffer_position] == ' ')
 	{
 	  skip_line(buffer, &buffer_position, buffer_length);
-	  continue;  
+	  continue;
 	}
 
       i = 0;
 
       line = read_line (buffer, buffer_length, &buffer_position);
 
+      debug (debug_utils, "parse_package: heidi = %s", line);
       /* Check the want list, to see if the line we have is one we need. */
       /* This code is horrible, sorry */
       while (want_list_pointer)
@@ -113,30 +114,35 @@ void parse_package (const char *buffer, long buffer_position, const int buffer_l
 	  /* Skip wants we already have */
 	  if (!((want_node *)(want_list_pointer->data))->found)
 	    {
-	      if (!strncmp (line, 
-			    ((want_node *)(want_list_pointer->data))->search_string,
-			    strlen (((want_node *)(want_list_pointer->data))->search_string)))
+	      if (!strncasecmp (line,
+				((want_node *)(want_list_pointer->data))->search_string,
+				strlen (((want_node *)(want_list_pointer->data))->search_string)))
 		{
-		  *((want_node *) want_list_pointer->data)->destination_string = 
+		  debug (debug_utils, "parse_package: match on  = %s", (((want_node *)(want_list_pointer->data))->search_string));
+		  *((want_node *) want_list_pointer->data)->destination_string =
 		    xstrdup (line + (strlen (((want_node *)(want_list_pointer->data))->search_string)));
 		  ((want_node *)(want_list_pointer->data))->found = TRUE;
 		  break;
 		}
 	    }
-	  
+
 	  want_list_pointer = want_list_pointer->next;
 	}
 
       xfree (line);
     }
 
+  buffer_position++;
+
+  return buffer_position;
+
 }
 
 /* A less heavy weight version of the above; retained because we only
    care about one or two fields in the secondary architecture */
 
 char *
-get_field (const char *buffer, const long buffer_length, long buffer_position, 
+get_field (const char *buffer, const long buffer_length, long buffer_position,
 	   const char *input, const char *package_name)
 {
 
@@ -157,7 +163,7 @@ get_field (const char *buffer, const long buffer_length, long buffer_position,
 	  field = read_line (buffer, buffer_length, &buffer_position);
 
 	  /* If we have a match stop searching, if not null the field string */
-	  if (!(strncmp (input, field, strlen(input)))) 
+	  if (!(strncasecmp (input, field, strlen(input))))
 	    {
 	      strmove (field, field + (strlen (input)));
 	      break;
@@ -173,12 +179,12 @@ get_field (const char *buffer, const long buffer_length, long buffer_position,
     }
 
   return field;
-  
+
 }
 
 void skip_line (const char *buffer, long *counter, const long buffer_length)
 {
-  
+
   while (*counter < buffer_length && buffer[*counter] != '\n')
     (*counter)++;
 
@@ -189,12 +195,12 @@ void skip_line (const char *buffer, long *counter, const long buffer_length)
 
 void skip_to_next_package (const char *buffer, long *buffer_position, const long buffer_length)
 {
- 
+
   while (*buffer_position < buffer_length && buffer[*buffer_position] !='\n')
     skip_line (buffer, buffer_position, buffer_length);
 
   if (*buffer_position < buffer_length)
-    (*buffer_position)++;    
+    (*buffer_position)++;
 
 }
 
@@ -203,7 +209,7 @@ read_line (const char *buffer, const long buffer_length, long *counter)
 {
 
   /* Reads in a line, allocating space on the fly */
-  
+
   int i = 0;
   int max_length = 256;
   char *line;
@@ -231,7 +237,7 @@ read_line (const char *buffer, const long buffer_length, long *counter)
 void read_file (const char *filename, FILE *fp, char **buffer_p, long *file_length)
 {
 
-  int n_read;                   
+  int n_read;
 
   fp = fopen (filename, "r");
   if (fp == NULL)
@@ -242,21 +248,25 @@ void read_file (const char *filename, FILE *fp, char **buffer_p, long *file_leng
   rewind (fp);
 
   if (*file_length == 0)
-    fubar (NONSYS, "read_file: \"%s\" is zero-length.", filename);
+    {
+      error ("read_file: \"%s\" is zero-length; hope you know what you're doing...", filename);
+      *buffer_p = NULL;
+    }
+  else
+    {
+      /* We don't do any memory management, we just ask for a chunk of
+       * memory the size of the file */
 
-  /* We don't do any memory management, we just ask for a chunk of
-   * memory the size of the file */
+      *buffer_p = (char *) xmalloc (*file_length);
 
-  *buffer_p = (char *) xmalloc (*file_length);
-
-  /* RUARI QUINN this is ignoring the possibility that ftell could be long */
-
-  n_read = fread (*buffer_p, sizeof (char), *file_length, fp);
-  if (n_read == 0)
-    fubar (SYSERR, "read_file: couldn't read file \"%s\" into buffer", filename);
-  else if (n_read < *file_length)
-    fubar (NONSYS, "read_file: short read (found %d, expected %ld) in file \"%s\"",
-	   n_read, *file_length, filename);
+      /* RUARI QUINN this is ignoring the possibility that ftell could be long */
+      n_read = fread (*buffer_p, sizeof (char), *file_length, fp);
+      if (n_read == 0)
+	fubar (SYSERR, "read_file: couldn't read file \"%s\" into buffer", filename);
+      else if (n_read < *file_length)
+	fubar (NONSYS, "read_file: short read (found %d, expected %ld) in file \"%s\"",
+	       n_read, *file_length, filename);
+    }
 
   if (fclose (fp) == EOF)
     fubar (SYSERR, "read_file: couldn't close file \"%s\"", filename);
