@@ -24,8 +24,8 @@
 
 guint quinn_hash_function (gconstpointer keyarg);
 gint quinn_key_compare_function (gconstpointer a, gconstpointer b);
-void parse_package (const char *buffer, long buffer_position, const int buffer_length, 
-		    Qlist *want_list, const char *package_name);
+long parse_package (const char *buffer, long buffer_position, const int buffer_length, 
+		    Qlist *want_list);
 char *get_field (const char *buffer, const long buffer_length, long buffer_position, 
 		const char *input, const char *package_name);
 void skip_line (const char *buffer, long *counter, const long buffer_length);
