@@ -4,7 +4,7 @@
  * Cut to shreds and altered for Quinn Diff.
  *
  * Copyright (C) 1995 Ian Jackson <iwj10@cus.cam.ac.uk>
- * Copyright (C) 1997-1999 James Troup <james@nocrew.org>
+ * Copyright (C) 1997-2001 James Troup <james@nocrew.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as
@@ -30,7 +30,6 @@
 #include "xmalloc.h"
 #include "nfmalloc.h"
 #include "vercmp.h"
-#include "main.h"
 
 struct versionrevision source_version;
 struct versionrevision binary_version;
@@ -129,7 +128,7 @@ compare_versions (const char *source_version_string,
 	   binary_version_string, package, error_msg); 
    
   debug (debug_versions, 
-	 "comparing %s: [Primary] %ld:%s-%s (was %s) versus [Secondary] %ld:%s-%s (was %s), result is %d", 
+	 "comparing %s: [Source] %ld:%s-%s (was %s) versus [Binary] %ld:%s-%s (was %s), result is %d", 
 	 package, source_version.epoch, source_version.version, source_version.revision,
 	 source_version_string, binary_version.epoch, binary_version.version, binary_version.revision, 
 	 binary_version_string, versioncompare (&binary_version, &source_version));
